@@ -5,25 +5,24 @@ use 5.014;
 use warnings;
 use open qw/:encoding(UTF-8) :std/;
 
-use Net::DNS;
 use Net::Whois::Norid;
 use Net::Whois::Raw;
 
 $Net::Whois::Raw::CHECK_FAIL = 1;
 $Net::Whois::Raw::OMIT_MSG   = 1;
 
-use version; our $VERSION = qv('0.9.0');
+use version; our $VERSION = qv('0.9.1');
 
 use parent qw/Exporter/;
 our @EXPORT_OK = qw/all domain2orgnr num_domains orgnr_ok orgnr2domains/;
 our %EXPORT_TAGS = ( 'all' => [qw/domain2orgnr num_domains orgnr_ok orgnr2domains/] );
 
 sub domain2orgnr {
-    my $domain = shift || return;
+    my $domain = shift or return;
 
-    return if $domain !~ / [.] no \z /x;
-
-    return if !Net::DNS::Resolver->new->search($domain);
+    if ( $domain !~ / [.] no \z /x ) {
+        return;
+    }
 
     return Net::Whois::Norid->new($domain)->id_number;
 }
@@ -31,34 +30,28 @@ sub domain2orgnr {
 sub num_domains {
     my $orgnr = shift;
 
-    return 0 if not orgnr_ok($orgnr);
-
-    $orgnr =~ s/\s//g;
-
-    # Verifying if orgnr owns any domain names
-    my $res = whois( $orgnr, 'whois.norid.no' );
-    return 0 if !defined $res;
-
-    return Net::Whois::Norid->new($orgnr)->total_number_of_domains;
+    return scalar orgnr2domains($orgnr);
 }
 
 sub orgnr2domains {
     my $orgnr = shift;
 
-    return () if not orgnr_ok($orgnr);
+    my @domains;
 
-    $orgnr =~ s/\s//g;
+    if ( !orgnr_ok($orgnr) ) {
+        return @domains;
+    }
 
-    # Verifying if orgnr owns any domain names
-    my $res = whois( $orgnr, 'whois.norid.no' );
-    return () if !defined $res;
+    $orgnr =~ s/ \s //gx;
 
-    my $whois = Net::Whois::Norid->new($orgnr);
+    my $whois        = Net::Whois::Norid->new($orgnr);
+    my $norid_handle = $whois->norid_handle;
 
-    my @domains = ();
+    if ( !defined $norid_handle ) {
+        return @domains;
+    }
 
-  HANDLE:
-    for my $nh ( split / \n /x, $whois->norid_handle ) {
+    for my $nh ( split / \n /x, $norid_handle ) {
         my $nhobj = Net::Whois::Norid->new($nh);
 
         for my $domain ( split / /, $nhobj->domains ) {
@@ -70,13 +63,14 @@ sub orgnr2domains {
 }
 
 sub orgnr_ok {
-    my $orgnr = shift // '';
-    return 0 if !$orgnr;
+    my $orgnr = shift or return 0;
 
-    $orgnr =~ s/\s//g;
+    $orgnr =~ s/ \s //gx;
 
     # Valid numbers start on 8 or 9
-    return 0 if $orgnr !~ /\A [89] \d{8} \z/ax;
+    if ( $orgnr !~ /\A [89] \d{8} \z/ax ) {
+        return 0;
+    }
 
     my @d = split //, $orgnr;
     my $w = [ 3, 2, 7, 6, 5, 4, 3, 2 ];
@@ -89,9 +83,13 @@ sub orgnr_ok {
     my $control_digit = ( $rem == 0 ? 0 : 11 - $rem );
 
     # Invalid number if control digit is 10
-    return 0 if $rem == 1;
+    if ( $control_digit == 10 ) {
+        return 0;
+    }
 
-    return 0 if $control_digit ne $d[8];
+    if ( $control_digit != $d[8] ) {
+        return 0;
+    }
 
     return $d[0] . $d[1] . $d[2] . ' ' . $d[3] . $d[4] . $d[5] . ' ' . $d[6] . $d[7] . $d[8];
 }
@@ -114,26 +112,25 @@ No::OrgNr - Utility functions for Norwegian organizations' ID numbers
 
 =head1 VERSION
 
-This document describes No::OrgNr version 0.9.0
+This document describes No::OrgNr version 0.9.1
 
 =head1 SYNOPSIS
 
-    use No::OrgNr qw/domain2orgnr orgnr2domains orgnr_ok/;
+    use No::OrgNr qw/domain2orgnr num_domains orgnr2domains orgnr_ok/;
     # or
     use No::OrgNr qw/:all/;
 
     my $owner   = domain2orgnr('google.no'); # Returns "988588261", as seen by Whois
     my $num     = num_domains(ORG_NR);       # Returns the number of domain names owned by ORG_NR
-    my $test    = orgnr_ok('988588261');     # Returns "988 588 261"
+    my $orgnr   = orgnr_ok('988588261');     # Returns "988 588 261"
     my @domains = orgnr2domains(ORG_NR);     # Returns a list of domain names owned by ORG_NR
 
 =head1 DESCRIPTION
 
-Organizations in Norway have a 9-digit number for identification. Valid numbers start with 8 or
-9. No information about the given organization can be derived from the number.
+Organizations in Norway have a 9-digit number for identification. Valid numbers start on 8 or 9. No
+information about the given organization can be derived from the number.
 
-This module contains utility functions for handling these numbers. Domain names owned by Norwegian
-organizations can also be listed, given their organization number.
+This module contains utility functions for handling these numbers.
 
 Please keep in mind that this module utilizes the module C<Net::Whois::Norid>, which in turn uses
 the server C<whois.norid.no>. This server has a limitation for the number of requests. See
@@ -142,7 +139,7 @@ documentation at L<https://www.norid.no/en/registrar/system/tjenester/whois-das-
 The Norwegian term for organization number is "organisasjonsnummer". See
 L<https://no.wikipedia.org/wiki/Organisasjonsnummer> for a description (Norwegian text only).
 
-Organizations in other countries also have ID numbers. See
+Organizations in other countries have ID numbers as well. See
 L<https://en.wikipedia.org/wiki/VAT_identification_number>.
 
 =head1 SUBROUTINES/METHODS
@@ -156,14 +153,14 @@ names (*.no) are supported. If no organization number can be found, the undefine
 
 =head2 num_domains(ORG_NR)
 
-The function returns the number of domain names owned by organization number C<ORG_NR>. The output
-is 0 (zero) if no such domain name exists.
+The function returns the number of domain names owned by organization number C<ORG_NR>. The value is
+zero if no such domain name exists.
 
 =head2 orgnr2domains(ORG_NR)
 
-The function returns a sorted list of domain names (if any) owned by
-organization number C<ORG_NR>. If C<ORG_NR> is missing or invalid, or the
-organization does not own a domain name, an empty list is returned.
+The function returns a sorted list of domain names (if any) owned by organization number C<ORG_NR>.
+If C<ORG_NR> is missing or invalid, or the organization does not own a domain name, an empty list is
+returned.
 
 =head2 orgnr_ok(ORG_NR)
 
@@ -249,10 +246,9 @@ Geir Myklebust C<< <geirmy@cpan.org> >>
 
 No::OrgNr is Copyright (C) 2015, 2016, Geir Myklebust.
 
-This module is free software; you can redistribute it and/or modify it under the
-same terms as Perl 5.14.0. For details, see L<GNU General Public
-License|https://metacpan.org/pod/perlgpl> and L<Perl Artistic
-License|https://metacpan.org/pod/perlartistic>.
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl
+5.14.0. For details, see L<GNU General Public License|https://metacpan.org/pod/perlgpl> and L<Perl
+Artistic License|https://metacpan.org/pod/perlartistic>.
 
-This program is distributed in the hope that it will be useful, but it is
-provided "as is" and without any express or implied warranties.
+This program is distributed in the hope that it will be useful, but it is provided "as is" and
+without any express or implied warranties.
